@@ -1,92 +1,93 @@
+"""avi http://www.uif.shcp.gob.mx/recepcion/avi"""
 from decimal import Decimal
 from datetime import datetime, date, time
 from collections.abc import Sequence
-from ...cfdi import CFDI, XElement
+from ... import CFDI, XElement, ScalarMap
 
 
-class CuentaExtranjeraType(XElement):
+class CuentaExtranjeraType(ScalarMap):
+    """
+    
+    :param numero_cuenta:
+    :param nombre_banco:
+    """
+    
     def __init__(
             self,
             numero_cuenta: str,
             nombre_banco: str,
     ): 
-        """
-        
-        :param numero_cuenta:
-        :param nombre_banco:
-        """
-        
         super().__init__({
             'NumeroCuenta': numero_cuenta,
             'NombreBanco': nombre_banco,
         })
         
 
-class CuentaNacionalType(XElement):
+class CuentaNacionalType(ScalarMap):
+    """
+    
+    :param clabe_destino:
+    :param clave_institucion_financiera:
+    """
+    
     def __init__(
             self,
             clabe_destino: str,
             clave_institucion_financiera: int,
     ): 
-        """
-        
-        :param clabe_destino:
-        :param clave_institucion_financiera:
-        """
-        
         super().__init__({
             'ClabeDestino': clabe_destino,
             'ClaveInstitucionFinanciera': clave_institucion_financiera,
         })
         
 
-class PaisCuentaType(XElement):
+class PaisCuentaType(ScalarMap):
+    """
+    
+    :param nacional:
+    :param extranjero:
+    """
+    
     def __init__(
             self,
             nacional: CuentaNacionalType | dict = None,
             extranjero: CuentaExtranjeraType | dict = None,
     ): 
-        """
-        
-        :param nacional:
-        :param extranjero:
-        """
-        
         super().__init__({
             'Nacional': nacional,
             'Extranjero': extranjero,
         })
         
 
-class PersonaMoralBasicoType(XElement):
+class PersonaMoralBasicoType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
     ): 
-        """
-        
-        :param denominacion_razon:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
         })
         
 
-class PersonaFisicaBasicoType(XElement):
+class PersonaFisicaBasicoType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    """
+    
     def __init__(
             self,
             nombre: str,
             apellido_paterno: str,
             apellido_materno: str,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -94,61 +95,69 @@ class PersonaFisicaBasicoType(XElement):
         })
         
 
-class TipoPersonaBasicoType(XElement):
+class TipoPersonaBasicoType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaBasicoType | dict = None,
             persona_moral: PersonaMoralBasicoType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
         })
         
 
-class PersonaCuentaType(XElement):
+class PersonaCuentaType(ScalarMap):
+    """
+    
+    :param tipo_persona:
+    :param nacionalidad_cuenta:
+    """
+    
     def __init__(
             self,
             tipo_persona: TipoPersonaBasicoType | dict,
             nacionalidad_cuenta: PaisCuentaType | dict,
     ): 
-        """
-        
-        :param tipo_persona:
-        :param nacionalidad_cuenta:
-        """
-        
         super().__init__({
             'TipoPersona': tipo_persona,
             'NacionalidadCuenta': nacionalidad_cuenta,
         })
         
 
-class ActivoVirtualCompuestoType(XElement):
+class ActivoVirtualCompuestoType(ScalarMap):
+    """
+    
+    :param activo_virtual:
+    :param monto_operacion_mn:
+    """
+    
     def __init__(
             self,
             activo_virtual: ActivoVirtualSimpleType | dict,
             monto_operacion_mn: str,
     ): 
-        """
-        
-        :param activo_virtual:
-        :param monto_operacion_mn:
-        """
-        
         super().__init__({
             'ActivoVirtual': activo_virtual,
             'MontoOperacionMn': monto_operacion_mn,
         })
         
 
-class ActivoVirtualSimpleType(XElement):
+class ActivoVirtualSimpleType(ScalarMap):
+    """
+    
+    :param activo_virtual_operado:
+    :param tipo_cambio_mn:
+    :param cantidad_activo_virtual:
+    :param descripcion_activo_virtual:
+    """
+    
     def __init__(
             self,
             activo_virtual_operado: int,
@@ -156,14 +165,6 @@ class ActivoVirtualSimpleType(XElement):
             cantidad_activo_virtual: str,
             descripcion_activo_virtual: str = None,
     ): 
-        """
-        
-        :param activo_virtual_operado:
-        :param tipo_cambio_mn:
-        :param cantidad_activo_virtual:
-        :param descripcion_activo_virtual:
-        """
-        
         super().__init__({
             'ActivoVirtualOperado': activo_virtual_operado,
             'TipoCambioMn': tipo_cambio_mn,
@@ -172,7 +173,16 @@ class ActivoVirtualSimpleType(XElement):
         })
         
 
-class DepositoType(XElement):
+class DepositoType(ScalarMap):
+    """
+    
+    :param fecha_hora_operacion:
+    :param instrumento_monetario:
+    :param moneda_operacion:
+    :param monto_operacion:
+    :param datos_ordenante:
+    """
+    
     def __init__(
             self,
             fecha_hora_operacion: str,
@@ -181,15 +191,6 @@ class DepositoType(XElement):
             monto_operacion: str,
             datos_ordenante: PersonaCuentaType | dict,
     ): 
-        """
-        
-        :param fecha_hora_operacion:
-        :param instrumento_monetario:
-        :param moneda_operacion:
-        :param monto_operacion:
-        :param datos_ordenante:
-        """
-        
         super().__init__({
             'FechaHoraOperacion': fecha_hora_operacion,
             'InstrumentoMonetario': instrumento_monetario,
@@ -199,7 +200,16 @@ class DepositoType(XElement):
         })
         
 
-class RetiroType(XElement):
+class RetiroType(ScalarMap):
+    """
+    
+    :param fecha_hora_operacion:
+    :param instrumento_monetario:
+    :param moneda_operacion:
+    :param monto_operacion:
+    :param datos_beneficiario:
+    """
+    
     def __init__(
             self,
             fecha_hora_operacion: str,
@@ -208,15 +218,6 @@ class RetiroType(XElement):
             monto_operacion: str,
             datos_beneficiario: PersonaCuentaType | dict,
     ): 
-        """
-        
-        :param fecha_hora_operacion:
-        :param instrumento_monetario:
-        :param moneda_operacion:
-        :param monto_operacion:
-        :param datos_beneficiario:
-        """
-        
         super().__init__({
             'FechaHoraOperacion': fecha_hora_operacion,
             'InstrumentoMonetario': instrumento_monetario,
@@ -226,7 +227,15 @@ class RetiroType(XElement):
         })
         
 
-class RecepcionType(XElement):
+class RecepcionType(ScalarMap):
+    """
+    
+    :param fecha_hora_operacion:
+    :param monto_operacion_mn:
+    :param activo_virtual:
+    :param hash_operacion:
+    """
+    
     def __init__(
             self,
             fecha_hora_operacion: str,
@@ -234,14 +243,6 @@ class RecepcionType(XElement):
             activo_virtual: ActivoVirtualSimpleType | dict,
             hash_operacion: str,
     ): 
-        """
-        
-        :param fecha_hora_operacion:
-        :param monto_operacion_mn:
-        :param activo_virtual:
-        :param hash_operacion:
-        """
-        
         super().__init__({
             'FechaHoraOperacion': fecha_hora_operacion,
             'MontoOperacionMn': monto_operacion_mn,
@@ -250,7 +251,15 @@ class RecepcionType(XElement):
         })
         
 
-class EnvioType(XElement):
+class EnvioType(ScalarMap):
+    """
+    
+    :param fecha_hora_operacion:
+    :param monto_operacion_mn:
+    :param activo_virtual:
+    :param hash_operacion:
+    """
+    
     def __init__(
             self,
             fecha_hora_operacion: str,
@@ -258,14 +267,6 @@ class EnvioType(XElement):
             activo_virtual: ActivoVirtualSimpleType | dict,
             hash_operacion: str,
     ): 
-        """
-        
-        :param fecha_hora_operacion:
-        :param monto_operacion_mn:
-        :param activo_virtual:
-        :param hash_operacion:
-        """
-        
         super().__init__({
             'FechaHoraOperacion': fecha_hora_operacion,
             'MontoOperacionMn': monto_operacion_mn,
@@ -274,7 +275,15 @@ class EnvioType(XElement):
         })
         
 
-class IntercambioType(XElement):
+class IntercambioType(ScalarMap):
+    """
+    
+    :param fecha_hora_operacion:
+    :param activo_virtual_enviado:
+    :param activo_virtual_recibido:
+    :param hash_operacion:
+    """
+    
     def __init__(
             self,
             fecha_hora_operacion: str,
@@ -282,14 +291,6 @@ class IntercambioType(XElement):
             activo_virtual_recibido: ActivoVirtualCompuestoType | dict,
             hash_operacion: str,
     ): 
-        """
-        
-        :param fecha_hora_operacion:
-        :param activo_virtual_enviado:
-        :param activo_virtual_recibido:
-        :param hash_operacion:
-        """
-        
         super().__init__({
             'FechaHoraOperacion': fecha_hora_operacion,
             'ActivoVirtualEnviado': activo_virtual_enviado,
@@ -298,7 +299,16 @@ class IntercambioType(XElement):
         })
         
 
-class VentaType(XElement):
+class VentaType(ScalarMap):
+    """
+    
+    :param fecha_hora_operacion:
+    :param moneda_operacion:
+    :param monto_operacion:
+    :param activo_virtual:
+    :param hash_operacion:
+    """
+    
     def __init__(
             self,
             fecha_hora_operacion: str,
@@ -307,15 +317,6 @@ class VentaType(XElement):
             activo_virtual: ActivoVirtualSimpleType | dict,
             hash_operacion: str,
     ): 
-        """
-        
-        :param fecha_hora_operacion:
-        :param moneda_operacion:
-        :param monto_operacion:
-        :param activo_virtual:
-        :param hash_operacion:
-        """
-        
         super().__init__({
             'FechaHoraOperacion': fecha_hora_operacion,
             'MonedaOperacion': moneda_operacion,
@@ -325,7 +326,16 @@ class VentaType(XElement):
         })
         
 
-class CompraType(XElement):
+class CompraType(ScalarMap):
+    """
+    
+    :param fecha_hora_operacion:
+    :param moneda_operacion:
+    :param monto_operacion:
+    :param activo_virtual:
+    :param hash_operacion:
+    """
+    
     def __init__(
             self,
             fecha_hora_operacion: str,
@@ -334,15 +344,6 @@ class CompraType(XElement):
             activo_virtual: ActivoVirtualSimpleType | dict,
             hash_operacion: str,
     ): 
-        """
-        
-        :param fecha_hora_operacion:
-        :param moneda_operacion:
-        :param monto_operacion:
-        :param activo_virtual:
-        :param hash_operacion:
-        """
-        
         super().__init__({
             'FechaHoraOperacion': fecha_hora_operacion,
             'MonedaOperacion': moneda_operacion,
@@ -352,148 +353,157 @@ class CompraType(XElement):
         })
         
 
-class FondosDepositadosType(XElement):
+class FondosDepositadosType(ScalarMap):
+    """
+    
+    :param deposito:
+    """
+    
     def __init__(
             self,
             deposito: DepositoType | dict | Sequence[DepositoType | dict],
     ): 
-        """
-        
-        :param deposito:
-        """
-        
         super().__init__({
             'Deposito': deposito,
         })
         
 
-class FondosRetiradosType(XElement):
+class FondosRetiradosType(ScalarMap):
+    """
+    
+    :param retiro:
+    """
+    
     def __init__(
             self,
             retiro: RetiroType | dict | Sequence[RetiroType | dict],
     ): 
-        """
-        
-        :param retiro:
-        """
-        
         super().__init__({
             'Retiro': retiro,
         })
         
 
-class OperacionesFondosType(XElement):
+class OperacionesFondosType(ScalarMap):
+    """
+    
+    :param fondos_retirados:
+    :param fondos_depositados:
+    """
+    
     def __init__(
             self,
             fondos_retirados: FondosRetiradosType | dict = None,
             fondos_depositados: FondosDepositadosType | dict = None,
     ): 
-        """
-        
-        :param fondos_retirados:
-        :param fondos_depositados:
-        """
-        
         super().__init__({
             'FondosRetirados': fondos_retirados,
             'FondosDepositados': fondos_depositados,
         })
         
 
-class TransferenciasRecibidasType(XElement):
+class TransferenciasRecibidasType(ScalarMap):
+    """
+    
+    :param recepcion:
+    """
+    
     def __init__(
             self,
             recepcion: RecepcionType | dict | Sequence[RecepcionType | dict],
     ): 
-        """
-        
-        :param recepcion:
-        """
-        
         super().__init__({
             'Recepcion': recepcion,
         })
         
 
-class TransferenciasEnviadasType(XElement):
+class TransferenciasEnviadasType(ScalarMap):
+    """
+    
+    :param envio:
+    """
+    
     def __init__(
             self,
             envio: EnvioType | dict | Sequence[EnvioType | dict],
     ): 
-        """
-        
-        :param envio:
-        """
-        
         super().__init__({
             'Envio': envio,
         })
         
 
-class OperacionesTransferenciaType(XElement):
+class OperacionesTransferenciaType(ScalarMap):
+    """
+    
+    :param transferencias_enviadas:
+    :param transferencias_recibidas:
+    """
+    
     def __init__(
             self,
             transferencias_enviadas: TransferenciasEnviadasType | dict = None,
             transferencias_recibidas: TransferenciasRecibidasType | dict = None,
     ): 
-        """
-        
-        :param transferencias_enviadas:
-        :param transferencias_recibidas:
-        """
-        
         super().__init__({
             'TransferenciasEnviadas': transferencias_enviadas,
             'TransferenciasRecibidas': transferencias_recibidas,
         })
         
 
-class OperacionesIntercambioType(XElement):
+class OperacionesIntercambioType(ScalarMap):
+    """
+    
+    :param intercambio:
+    """
+    
     def __init__(
             self,
             intercambio: IntercambioType | dict | Sequence[IntercambioType | dict],
     ): 
-        """
-        
-        :param intercambio:
-        """
-        
         super().__init__({
             'Intercambio': intercambio,
         })
         
 
-class OperacionesVentaType(XElement):
+class OperacionesVentaType(ScalarMap):
+    """
+    
+    :param venta:
+    """
+    
     def __init__(
             self,
             venta: VentaType | dict | Sequence[VentaType | dict],
     ): 
-        """
-        
-        :param venta:
-        """
-        
         super().__init__({
             'Venta': venta,
         })
         
 
-class OperacionesCompraType(XElement):
+class OperacionesCompraType(ScalarMap):
+    """
+    
+    :param compra:
+    """
+    
     def __init__(
             self,
             compra: CompraType | dict | Sequence[CompraType | dict],
     ): 
-        """
-        
-        :param compra:
-        """
-        
         super().__init__({
             'Compra': compra,
         })
         
 
-class DetalleOperacionesType(XElement):
+class DetalleOperacionesType(ScalarMap):
+    """
+    
+    :param operaciones_compra:
+    :param operaciones_venta:
+    :param operaciones_intercambio:
+    :param operaciones_transferencia:
+    :param operaciones_fondos:
+    """
+    
     def __init__(
             self,
             operaciones_compra: OperacionesCompraType | dict = None,
@@ -502,15 +512,6 @@ class DetalleOperacionesType(XElement):
             operaciones_transferencia: OperacionesTransferenciaType | dict = None,
             operaciones_fondos: OperacionesFondosType | dict = None,
     ): 
-        """
-        
-        :param operaciones_compra:
-        :param operaciones_venta:
-        :param operaciones_intercambio:
-        :param operaciones_transferencia:
-        :param operaciones_fondos:
-        """
-        
         super().__init__({
             'OperacionesCompra': operaciones_compra,
             'OperacionesVenta': operaciones_venta,
@@ -520,20 +521,20 @@ class DetalleOperacionesType(XElement):
         })
         
 
-class FideicomisoSimpleType(XElement):
+class FideicomisoSimpleType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param rfc:
+    :param identificador_fideicomiso:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
             rfc: str = None,
             identificador_fideicomiso: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param rfc:
-        :param identificador_fideicomiso:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'Rfc': rfc,
@@ -541,7 +542,15 @@ class FideicomisoSimpleType(XElement):
         })
         
 
-class PersonaMoralSimpleType(XElement):
+class PersonaMoralSimpleType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param pais_nacionalidad:
+    :param fecha_constitucion:
+    :param rfc:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -549,14 +558,6 @@ class PersonaMoralSimpleType(XElement):
             fecha_constitucion: date = None,
             rfc: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param pais_nacionalidad:
-        :param fecha_constitucion:
-        :param rfc:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'PaisNacionalidad': pais_nacionalidad,
@@ -565,7 +566,18 @@ class PersonaMoralSimpleType(XElement):
         })
         
 
-class PersonaFisicaSimpleType(XElement):
+class PersonaFisicaSimpleType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param pais_nacionalidad:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -576,17 +588,6 @@ class PersonaFisicaSimpleType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param pais_nacionalidad:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -598,20 +599,20 @@ class PersonaFisicaSimpleType(XElement):
         })
         
 
-class TipoPersonaSimpleType(XElement):
+class TipoPersonaSimpleType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaSimpleType | dict = None,
             persona_moral: PersonaMoralSimpleType | dict = None,
             fideicomiso: FideicomisoSimpleType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -619,35 +620,35 @@ class TipoPersonaSimpleType(XElement):
         })
         
 
-class DuenoBeneficiarioType(XElement):
+class DuenoBeneficiarioType(ScalarMap):
+    """
+    
+    :param tipo_persona:
+    """
+    
     def __init__(
             self,
             tipo_persona: TipoPersonaSimpleType | dict,
     ): 
-        """
-        
-        :param tipo_persona:
-        """
-        
         super().__init__({
             'TipoPersona': tipo_persona,
         })
         
 
-class TelefonoType(XElement):
+class TelefonoType(ScalarMap):
+    """
+    
+    :param clave_pais:
+    :param numero_telefono:
+    :param correo_electronico:
+    """
+    
     def __init__(
             self,
             clave_pais: str,
             numero_telefono: str,
             correo_electronico: str,
     ): 
-        """
-        
-        :param clave_pais:
-        :param numero_telefono:
-        :param correo_electronico:
-        """
-        
         super().__init__({
             'ClavePais': clave_pais,
             'NumeroTelefono': numero_telefono,
@@ -655,7 +656,19 @@ class TelefonoType(XElement):
         })
         
 
-class ExtranjeroType(XElement):
+class ExtranjeroType(ScalarMap):
+    """
+    
+    :param pais:
+    :param estado_provincia:
+    :param ciudad_poblacion:
+    :param colonia:
+    :param calle:
+    :param numero_exterior:
+    :param codigo_postal:
+    :param numero_interior:
+    """
+    
     def __init__(
             self,
             pais: str,
@@ -667,18 +680,6 @@ class ExtranjeroType(XElement):
             codigo_postal: str,
             numero_interior: str = None,
     ): 
-        """
-        
-        :param pais:
-        :param estado_provincia:
-        :param ciudad_poblacion:
-        :param colonia:
-        :param calle:
-        :param numero_exterior:
-        :param codigo_postal:
-        :param numero_interior:
-        """
-        
         super().__init__({
             'Pais': pais,
             'EstadoProvincia': estado_provincia,
@@ -691,7 +692,16 @@ class ExtranjeroType(XElement):
         })
         
 
-class NacionalType(XElement):
+class NacionalType(ScalarMap):
+    """
+    
+    :param colonia:
+    :param calle:
+    :param numero_exterior:
+    :param codigo_postal:
+    :param numero_interior:
+    """
+    
     def __init__(
             self,
             colonia: str,
@@ -700,15 +710,6 @@ class NacionalType(XElement):
             codigo_postal: str,
             numero_interior: str = None,
     ): 
-        """
-        
-        :param colonia:
-        :param calle:
-        :param numero_exterior:
-        :param codigo_postal:
-        :param numero_interior:
-        """
-        
         super().__init__({
             'Colonia': colonia,
             'Calle': calle,
@@ -718,43 +719,54 @@ class NacionalType(XElement):
         })
         
 
-class TipoDomicilioType(XElement):
+class TipoDomicilioType(ScalarMap):
+    """
+    
+    :param nacional:
+    :param extranjero:
+    """
+    
     def __init__(
             self,
             nacional: NacionalType | dict = None,
             extranjero: ExtranjeroType | dict = None,
     ): 
-        """
-        
-        :param nacional:
-        :param extranjero:
-        """
-        
         super().__init__({
             'Nacional': nacional,
             'Extranjero': extranjero,
         })
         
 
-class DocumentoIdentificacionType(XElement):
+class DocumentoIdentificacionType(ScalarMap):
+    """
+    
+    :param tipo_identificacion:
+    :param numero_identificacion:
+    """
+    
     def __init__(
             self,
             tipo_identificacion: int,
             numero_identificacion: str,
     ): 
-        """
-        
-        :param tipo_identificacion:
-        :param numero_identificacion:
-        """
-        
         super().__init__({
             'TipoIdentificacion': tipo_identificacion,
             'NumeroIdentificacion': numero_identificacion,
         })
         
 
-class RepresentanteApoderadoType(XElement):
+class RepresentanteApoderadoType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param documento_identificacion:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -765,17 +777,6 @@ class RepresentanteApoderadoType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param documento_identificacion:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -787,7 +788,15 @@ class RepresentanteApoderadoType(XElement):
         })
         
 
-class FideicomisoType(XElement):
+class FideicomisoType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param apoderado_delegado:
+    :param rfc:
+    :param identificador_fideicomiso:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -795,14 +804,6 @@ class FideicomisoType(XElement):
             rfc: str = None,
             identificador_fideicomiso: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param apoderado_delegado:
-        :param rfc:
-        :param identificador_fideicomiso:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'ApoderadoDelegado': apoderado_delegado,
@@ -811,7 +812,17 @@ class FideicomisoType(XElement):
         })
         
 
-class PersonaMoralType(XElement):
+class PersonaMoralType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param pais_nacionalidad:
+    :param giro_mercantil:
+    :param representante_apoderado:
+    :param fecha_constitucion:
+    :param rfc:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -821,16 +832,6 @@ class PersonaMoralType(XElement):
             fecha_constitucion: date = None,
             rfc: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param pais_nacionalidad:
-        :param giro_mercantil:
-        :param representante_apoderado:
-        :param fecha_constitucion:
-        :param rfc:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'PaisNacionalidad': pais_nacionalidad,
@@ -841,7 +842,20 @@ class PersonaMoralType(XElement):
         })
         
 
-class PersonaFisicaType(XElement):
+class PersonaFisicaType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param pais_nacionalidad:
+    :param actividad_economica:
+    :param documento_identificacion:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -854,19 +868,6 @@ class PersonaFisicaType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param pais_nacionalidad:
-        :param actividad_economica:
-        :param documento_identificacion:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -880,20 +881,20 @@ class PersonaFisicaType(XElement):
         })
         
 
-class TipoPersonaType(XElement):
+class TipoPersonaType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaType | dict = None,
             persona_moral: PersonaMoralType | dict = None,
             fideicomiso: FideicomisoType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -901,7 +902,15 @@ class TipoPersonaType(XElement):
         })
         
 
-class DatosCuentaPlataformaType(XElement):
+class DatosCuentaPlataformaType(ScalarMap):
+    """
+    
+    :param id_usuario:
+    :param cuenta_relacionada:
+    :param moneda_cuenta:
+    :param clabe_interbancaria:
+    """
+    
     def __init__(
             self,
             id_usuario: str,
@@ -909,14 +918,6 @@ class DatosCuentaPlataformaType(XElement):
             moneda_cuenta: int,
             clabe_interbancaria: str = None,
     ): 
-        """
-        
-        :param id_usuario:
-        :param cuenta_relacionada:
-        :param moneda_cuenta:
-        :param clabe_interbancaria:
-        """
-        
         super().__init__({
             'IdUsuario': id_usuario,
             'CuentaRelacionada': cuenta_relacionada,
@@ -925,7 +926,15 @@ class DatosCuentaPlataformaType(XElement):
         })
         
 
-class PersonaAvisoType(XElement):
+class PersonaAvisoType(ScalarMap):
+    """
+    
+    :param datos_cuenta_plataforma:
+    :param tipo_persona:
+    :param tipo_domicilio:
+    :param telefono:
+    """
+    
     def __init__(
             self,
             datos_cuenta_plataforma: DatosCuentaPlataformaType | dict,
@@ -933,14 +942,6 @@ class PersonaAvisoType(XElement):
             tipo_domicilio: TipoDomicilioType | dict = None,
             telefono: TelefonoType | dict = None,
     ): 
-        """
-        
-        :param datos_cuenta_plataforma:
-        :param tipo_persona:
-        :param tipo_domicilio:
-        :param telefono:
-        """
-        
         super().__init__({
             'DatosCuentaPlataforma': datos_cuenta_plataforma,
             'TipoPersona': tipo_persona,
@@ -949,20 +950,20 @@ class PersonaAvisoType(XElement):
         })
         
 
-class OperacionesPersonaType(XElement):
+class OperacionesPersonaType(ScalarMap):
+    """
+    
+    :param persona_aviso:
+    :param detalle_operaciones:
+    :param dueno_beneficiario:
+    """
+    
     def __init__(
             self,
             persona_aviso: PersonaAvisoType | dict,
             detalle_operaciones: DetalleOperacionesType | dict,
             dueno_beneficiario: DuenoBeneficiarioType | dict | Sequence[DuenoBeneficiarioType | dict] = None,
     ): 
-        """
-        
-        :param persona_aviso:
-        :param detalle_operaciones:
-        :param dueno_beneficiario:
-        """
-        
         super().__init__({
             'PersonaAviso': persona_aviso,
             'DetalleOperaciones': detalle_operaciones,
@@ -970,43 +971,52 @@ class OperacionesPersonaType(XElement):
         })
         
 
-class AlertaType(XElement):
+class AlertaType(ScalarMap):
+    """
+    
+    :param tipo_alerta:
+    :param descripcion_alerta:
+    """
+    
     def __init__(
             self,
             tipo_alerta: str,
             descripcion_alerta: str = None,
     ): 
-        """
-        
-        :param tipo_alerta:
-        :param descripcion_alerta:
-        """
-        
         super().__init__({
             'TipoAlerta': tipo_alerta,
             'DescripcionAlerta': descripcion_alerta,
         })
         
 
-class ModificatorioType(XElement):
+class ModificatorioType(ScalarMap):
+    """
+    
+    :param folio_modificacion:
+    :param descripcion_modificacion:
+    """
+    
     def __init__(
             self,
             folio_modificacion: str,
             descripcion_modificacion: str,
     ): 
-        """
-        
-        :param folio_modificacion:
-        :param descripcion_modificacion:
-        """
-        
         super().__init__({
             'FolioModificacion': folio_modificacion,
             'DescripcionModificacion': descripcion_modificacion,
         })
         
 
-class AvisoType(XElement):
+class AvisoType(ScalarMap):
+    """
+    
+    :param referencia_aviso:
+    :param prioridad:
+    :param alerta:
+    :param operaciones_persona:
+    :param modificatorio:
+    """
+    
     def __init__(
             self,
             referencia_aviso: str,
@@ -1015,15 +1025,6 @@ class AvisoType(XElement):
             operaciones_persona: OperacionesPersonaType | dict,
             modificatorio: ModificatorioType | dict = None,
     ): 
-        """
-        
-        :param referencia_aviso:
-        :param prioridad:
-        :param alerta:
-        :param operaciones_persona:
-        :param modificatorio:
-        """
-        
         super().__init__({
             'ReferenciaAviso': referencia_aviso,
             'Prioridad': prioridad,
@@ -1033,7 +1034,16 @@ class AvisoType(XElement):
         })
         
 
-class SujetoObligadoType(XElement):
+class SujetoObligadoType(ScalarMap):
+    """
+    
+    :param clave_sujeto_obligado:
+    :param clave_actividad:
+    :param dominio_plataforma:
+    :param clave_entidad_colegiada:
+    :param exento:
+    """
+    
     def __init__(
             self,
             clave_sujeto_obligado: str,
@@ -1042,15 +1052,6 @@ class SujetoObligadoType(XElement):
             clave_entidad_colegiada: str = None,
             exento: str = None,
     ): 
-        """
-        
-        :param clave_sujeto_obligado:
-        :param clave_actividad:
-        :param dominio_plataforma:
-        :param clave_entidad_colegiada:
-        :param exento:
-        """
-        
         super().__init__({
             'ClaveSujetoObligado': clave_sujeto_obligado,
             'ClaveActividad': clave_actividad,
@@ -1060,20 +1061,20 @@ class SujetoObligadoType(XElement):
         })
         
 
-class InformeType(XElement):
+class InformeType(ScalarMap):
+    """
+    
+    :param mes_reportado:
+    :param sujeto_obligado:
+    :param aviso:
+    """
+    
     def __init__(
             self,
             mes_reportado: str,
             sujeto_obligado: SujetoObligadoType | dict,
             aviso: AvisoType | dict | Sequence[AvisoType | dict] = None,
     ): 
-        """
-        
-        :param mes_reportado:
-        :param sujeto_obligado:
-        :param aviso:
-        """
-        
         super().__init__({
             'MesReportado': mes_reportado,
             'SujetoObligado': sujeto_obligado,
@@ -1081,21 +1082,21 @@ class InformeType(XElement):
         })
         
 
-class ArchivoType(XElement):
+class ArchivoType(ScalarMap):
+    """
+    
+    :param informe:
+    """
+    
     def __init__(
             self,
             informe: InformeType | dict | Sequence[InformeType | dict],
     ): 
-        """
-        
-        :param informe:
-        """
-        
         super().__init__({
             'Informe': informe,
         })
         
 
-class Archivo(ArchivoType):
+class Archivo(ArchivoType, XElement):
     tag = '{http://www.uif.shcp.gob.mx/recepcion/avi}archivo'
 
